Modified bgp file name according to naming convention.

Change-Id: I403139b53fbc1a2dba894dfd39720707a52ba7cd
diff --git a/bgp/bgpio/src/main/java/org/onosproject/bgpio/types/attr/BgpPrefixAttrExtRouteTag.java b/bgp/bgpio/src/main/java/org/onosproject/bgpio/types/attr/BgpPrefixAttrExtRouteTag.java
index c5ac51b..bbe3a10 100755
--- a/bgp/bgpio/src/main/java/org/onosproject/bgpio/types/attr/BgpPrefixAttrExtRouteTag.java
+++ b/bgp/bgpio/src/main/java/org/onosproject/bgpio/types/attr/BgpPrefixAttrExtRouteTag.java
@@ -22,9 +22,9 @@
 import java.util.Objects;
 
 import org.jboss.netty.buffer.ChannelBuffer;
-import org.onosproject.bgpio.exceptions.BGPParseException;
-import org.onosproject.bgpio.types.BGPErrorType;
-import org.onosproject.bgpio.types.BGPValueType;
+import org.onosproject.bgpio.exceptions.BgpParseException;
+import org.onosproject.bgpio.types.BgpErrorType;
+import org.onosproject.bgpio.types.BgpValueType;
 import org.onosproject.bgpio.util.Validation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -34,7 +34,7 @@
 /**
  * Implements BGP prefix route Extended tag attribute.
  */
-public class BgpPrefixAttrExtRouteTag implements BGPValueType {
+public class BgpPrefixAttrExtRouteTag implements BgpValueType {
 
     protected static final Logger log = LoggerFactory
             .getLogger(BgpPrefixAttrExtRouteTag.class);
@@ -69,10 +69,10 @@
      *
      * @param cb ChannelBuffer
      * @return object of BgpPrefixAttrExtRouteTag
      * @throws BGPParseException while parsing BgpPrefixAttrExtRouteTag
      */
     public static BgpPrefixAttrExtRouteTag read(ChannelBuffer cb)
-            throws BGPParseException {
+            throws BgpParseException {
         ArrayList<Long> pfxExtRouteTag = new ArrayList<Long>();
         long temp;
 
@@ -80,8 +80,8 @@
         int len = lsAttrLength / ATTR_PREFIX_EXT_LEN;
 
         if (cb.readableBytes() < lsAttrLength) {
-            Validation.validateLen(BGPErrorType.UPDATE_MESSAGE_ERROR,
-                                   BGPErrorType.ATTRIBUTE_LENGTH_ERROR,
+            Validation.validateLen(BgpErrorType.UPDATE_MESSAGE_ERROR,
+                                   BgpErrorType.ATTRIBUTE_LENGTH_ERROR,
                                    lsAttrLength);
         }
@@ -69,10 +69,10 @@
      * @param cb ChannelBuffer
      * @return object of BgpPrefixAttrExtRouteTag
-     * @throws BGPParseException while parsing BgpPrefixAttrExtRouteTag
+     * @throws BgpParseException while parsing BgpPrefixAttrExtRouteTag
      */
     public static BgpPrefixAttrExtRouteTag read(ChannelBuffer cb)